//! Data structure measurement.

pub use ckb_occupied_capacity_core::{Capacity, Error, IntoCapacity, Ratio, Result};
pub use ckb_occupied_capacity_macros::capacity_bytes;
